==> abby-client-1.2.0.tgz: package/lib/expressionEvaluator.js <==

let evaluate = (instance, field, props) => {
    let evaluator = instance[field.type];
    return typeof evaluator === 'function' && evaluator.call(instance, field, props);
};

/**
 * @typedef LogicalOperator
 * @property {string} type
 * @property {Array.<LogicalOperator|ComparisonOperator>} fields
 */

/**
 * @typedef ComparisonOperator
 * @property {string} type
 * @property {string} key
 * @property {string|number|boolean} value
 */

/**
 * expression evaluator will parse logical and comparison operators
 */
class ExpressionEvaluator {

    /**
     * expects a single logical operator or comparison operator
     * @param {ComparisonOperator|LogicalOperator} q 
     * @param {*} props 
     */
    evaluate(q, props, logger = console) {
        if (typeof q !== 'object') {
            return true;
        }
        if (q.hasOwnProperty('type')) {
            return evaluate(this, q, props);
        } else {
            /**
             * possible invalid query, this can be improved using logging
             * returns true for backwards compatibility
             */
            logger.warn(`[abby-client]
invalid query passed to ExpressionEvaluator.
pass LogicalOperator or ComparisonOperator
query: ${q}`);
            return true;
        }
    }

    /**
     * 
     * @param {LogicalOperator} query 
     * @param {*} props 
     * @returns {boolean}
     */
    and(query, props) {
        return query.fields.every(field => evaluate(this, field, props));
    }
    /**
     * 
     * @param {LogicalOperator} query 
     * @param {*} props 
     * @returns {boolean}
     */
    or(query, props) {
        return query.fields.some(field => evaluate(this, field, props));
    }
    /**
     * 
     * @param {ComparisonOperator} field 
     * @param {*} props 
     * @returns {boolean}
     */
    eq(field, props) {
        return field.value === props[field.key];
    }

    /**
     * 
     * @param {ComparisonOperator} field 
     * @param {*} props 
     * @returns {boolean}
     */
    neq(field, props) {
        return field.value !== props[field.key];
    }
}

module.exports = new ExpressionEvaluator();

==> abby-client-1.2.3.tgz: package/lib/expressionEvaluator.js <==

let evaluate = (instance, field, props) => {
    let evaluator = instance[field.type];
    return typeof evaluator === 'function' && evaluator.call(instance, field, props);
};

/**
 * @typedef LogicalOperator
 * @property {string} type
 * @property {Array.<LogicalOperator|ComparisonOperator>} fields
 */

/**
 * @typedef ComparisonOperator
 * @property {string} type
 * @property {string} key
 * @property {string|number|boolean} value
 */

/**
 * expression evaluator will parse logical and comparison operators
 */
class ExpressionEvaluator {

    /**
     * expects a single logical operator or comparison operator
     * @param {ComparisonOperator|LogicalOperator} q 
     * @param {*} props 
     */
    evaluate(q, props) {
        if (typeof q !== 'object') {
            return true;
        }
        if (q.hasOwnProperty('type')) {
            return evaluate(this, q, props);
        } else {
            return true;
        }
    }

    /**
     * 
     * @param {LogicalOperator} query 
     * @param {*} props 
     * @returns {boolean}
     */
    and(query, props) {
        return query.fields.every(field => evaluate(this, field, props));
    }
    /**
     * 
     * @param {LogicalOperator} query 
     * @param {*} props 
     * @returns {boolean}
     */
    or(query, props) {
        return query.fields.some(field => evaluate(this, field, props));
    }
    /**
     * 
     * @param {ComparisonOperator} field 
     * @param {*} props 
     * @returns {boolean}
     */
    eq(field, props) {
        return field.value === props[field.key];
    }

    /**
     * 
     * @param {ComparisonOperator} field 
     * @param {*} props 
     * @returns {boolean}
     */
    neq(field, props) {
        return field.value !== props[field.key];
    }
}

module.exports = new ExpressionEvaluator();
